bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDDistribution.__init__
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDDistribution.__init__